=== modified file 'buildtools/Packager.pm'
--- buildtools/Packager.pm	2009-12-12 18:20:36 +0000
+++ buildtools/Packager.pm	2010-01-07 17:25:17 +0000
@@ -46,6 +46,61 @@
   $self->{locales} = \@locales;
 }
 
+sub readLocaleData
+{
+  my ($self, $localesDir) = @_;
+
+  $self->{localeData} = {};
+  $self->{name} = '';
+  $self->{description} = '';
+
+  foreach my $locale (@{$self->{locales}})
+  {
+    my $data = $self->readFile("$localesDir/$locale/meta.properties");
+    next unless defined $data;
+
+    $self->{localeData}{$locale} = {id => $locale};
+    while ($data =~ /^\s*(?![!#])(\S+)\s*=\s*(.+)$/mg)
+    {
+      if ($1 eq "name" || $1 eq "description" || $1 eq "translator")
+      {
+        $self->{localeData}{$locale}{$1} = $2;
+      }
+    }
+  }
+
+  if (exists($self->{localeData}{"en-US"}))
+  {
+    $self->{name} = $self->{localeData}{"en-US"}{name} if exists($self->{localeData}{"en-US"}{name});
+    $self->{description} = $self->{localeData}{"en-US"}{description} if exists($self->{localeData}{"en-US"}{description});
+    delete $self->{localeData}{"en-US"};
+  }
+
+  my $info = "";
+  foreach my $locale (values %{$self->{localeData}})
+  {
+    next unless (exists($locale->{translator}) && $locale->{translator}) ||
+                (exists($locale->{name}) && $locale->{name} && $locale->{name} ne $self->{name}) ||
+                (exists($locale->{description}) && $locale->{description} && $locale->{description} ne $self->{description});
+
+    my $translator = (exists($locale->{translator}) && $locale->{translator} ? "\t\t\t<em:translator>$locale->{translator}</em:translator>" : "");
+    $locale->{name} = $self->{name} unless exists($locale->{name}) && $locale->{name} && $locale->{name} ne $self->{name};
+    $locale->{description} = $self->{description} unless exists($locale->{description}) && $locale->{description} && $locale->{description} ne $self->{description};
+
+    $info .= <<EOT;
+\t<em:localized>
+\t\t<Description>
+\t\t\t<em:locale>$locale->{id}</em:locale>
+\t\t\t<em:name>$locale->{name}</em:name>
+\t\t\t<em:description>$locale->{description}</em:description>
+$translator
+\t\t</Description>
+\t</em:localized>
+EOT
+  }
+  $self->{localizedInfo} = $info;
+}
+
 sub rm_rec
 {
   my ($self, $dir) = @_;
@@ -95,6 +150,9 @@
       s/^((?:  )+)/"\t" x (length($1)\/2)/e;
       s/\{\{VERSION\}\}/$self->{version}/g if $extendedTextMode;
       s/\{\{BUILD\}\}/$self->{build}/g if $extendedTextMode;
+      s/\{\{NAME\}\}/$self->{name}/g if $extendedTextMode;
+      s/\{\{DESCRIPTION\}\}/$self->{description}/g if $extendedTextMode;
+      s/\{\{LOCALIZED\}\}/$self->{localizedInfo}/g if $extendedTextMode;
       if ($extendedTextMode && /\{\{LOCALE\}\}/)
       {
         my $loc = "";

=== modified file 'buildtools/create_xpi.pl'
--- buildtools/create_xpi.pl	2009-12-12 18:20:36 +0000
+++ buildtools/create_xpi.pl	2010-01-07 17:25:17 +0000
@@ -35,9 +35,10 @@
 my $pkg = Packager->new(\%params);
 $pkg->readVersion('version');
 $pkg->readLocales('chrome/locale') unless exists $params{locales};
+$pkg->readLocaleData('chrome/locale');
 
 chdir('chrome');
-$pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete');
+$pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete', '-/meta.properties');
 chdir('..');
 
 my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');

=== added file 'buildtools/make_babelzilla_build.pl'
--- buildtools/make_babelzilla_build.pl	1970-01-01 00:00:00 +0000
+++ buildtools/make_babelzilla_build.pl	2010-01-07 17:25:17 +0000
@@ -0,0 +1,71 @@
+#!/usr/bin/perl
+
+#############################################################################
+# This script will create a special development build meant only for upload #
+# to Babelzilla.                                                            #
+#############################################################################
+
+use strict;
+use warnings;
+use lib qw(buildtools);
+use Packager;
+
+sub Packager::fixLocales() {}
+
+my $manifest = readFile("chrome.manifest");
+unless ($manifest =~ /\bjar:chrome\/(\S+?)\.jar\b/)
+{
+  die "Could not find JAR file name in chrome.manifest";
+}
+my $baseName = $1;
+
+my %params = ();
+$params{version} = shift @ARGV;
+die "Please specify version number on command line" unless $params{version};
+
+my $xpiFile = "$baseName-$params{version}.xpi";
+
+my $pkg = Packager->new(\%params);
+$pkg->readLocales('chrome/locale', 1);
+$pkg->readLocaleData('chrome/locale');
+
+chdir('chrome');
+$pkg->makeJAR("$baseName.jar", 'content', 'skin', 'locale', '-/tests', '-/mochitest', '-/.incomplete');
+chdir('..');
+
+my @files = grep {-e $_} ('components', 'defaults', 'install.rdf', 'chrome.manifest', 'icon.png');
+
+my $targetAppNum = 0;
+$pkg->{postprocess_line} = \&postprocessInstallRDF;
+$pkg->makeXPI($xpiFile, "chrome/$baseName.jar", @files);
+unlink("chrome/$baseName.jar");
+
+sub postprocessInstallRDF
+{
+  my ($file, $line) = @_;
+
+  return $line unless $file eq "install.rdf";
+
+  if ($line =~ /\btargetApplication\b/)
+  {
+    $targetAppNum++;
+    return "" if $targetAppNum > 6;
+  }
+
+  return "" if $targetAppNum > 6 && $targetAppNum % 2 == 1;
+
+  return $line;
+}
+
+sub readFile
+{
+  my $file = shift;
+
+  open(local *FILE, "<", $file) || die "Could not read file '$file'";
+  binmode(FILE);
+  local $/;
+  my $result = <FILE>;
+  close(FILE);
+
+  return $result;
+}

=== modified file 'buildtools/setupTestEnvironment.pl'
--- buildtools/setupTestEnvironment.pl	2009-12-12 18:20:36 +0000
+++ buildtools/setupTestEnvironment.pl	2010-01-07 17:25:17 +0000
@@ -20,14 +20,13 @@
 use strict;
 use warnings;
 use Cwd;
-
-my $version = readFile("version");
-$version =~ s/[^\w\.]//gs;
-
-opendir(local* LOCALES, "chrome/locale") || die "Could not read directory chrome/locales";
-my @locales = grep {!/[^\w\-]/} readdir(LOCALES);
-@locales = sort {$a eq "en-US" ? -1 : ($b eq "en-US" ? 1 : $a cmp $b)} @locales; 
-closedir(LOCALES);
+use lib qw(buildtools);
+use Packager;
+
+my $pkg = Packager->new();
+$pkg->readVersion('version');
+$pkg->readLocales('chrome/locale');
+$pkg->readLocaleData('chrome/locale');
 
 my @files = ();
 my $installManifest = fixupFile(readFile("install.rdf"));
@@ -142,12 +141,15 @@
 {
   my $str = shift;
 
-  $str =~ s/{{VERSION}}/$version/g;
+  $str =~ s/{{VERSION}}/$pkg->{version}/g;
   $str =~ s/{{BUILD}}//g;
+  $str =~ s/{{NAME}}/$pkg->{name}/g;
+  $str =~ s/{{DESCRIPTION}}/$pkg->{description}/g;
+  $str =~ s/{{LOCALIZED}}/$pkg->{localizedInfo}/g;
   $str =~ s/^.*{{LOCALE}}.*$/
     my @result = ();
     my $template = $&;
-    foreach my $locale (@locales)
+    foreach my $locale (@{$pkg->{locales}})
     {
       push(@result, $template);
       $result[-1] =~ s~{{LOCALE}}~$locale~g;

=== modified file 'chrome/content/prefs.js'
--- chrome/content/prefs.js	2009-12-12 18:20:36 +0000
+++ chrome/content/prefs.js	2010-01-07 17:25:17 +0000
@@ -296,9 +296,9 @@
   {
     if (topic == "private-browsing")
     {
-      if (prefName == "enter")
+      if (data == "enter")
         this.privateBrowsing = true;
-      else if (prefName == "exit")
+      else if (data == "exit")
         this.privateBrowsing = false;
     }
     else if (topic == "em-action-requested")

=== modified file 'chrome/content/ui/browserWindow.js'
--- chrome/content/ui/browserWindow.js	2009-12-12 18:20:36 +0000
+++ chrome/content/ui/browserWindow.js	2010-01-07 17:25:17 +0000
@@ -504,6 +504,9 @@
  */
 function showSubscriptions()
 {
+  // In Fennec we might not be initialized yet
+  abp.init();
+
   // Don't annoy the user if he has a subscription already
   let hasSubscriptions = filterStorage.subscriptions.some(function(subscription) subscription instanceof abp.DownloadableSubscription);
   if (hasSubscriptions)

=== modified file 'chrome/content/ui/subscriptions.xml'
--- chrome/content/ui/subscriptions.xml	2009-12-12 18:20:36 +0000
+++ chrome/content/ui/subscriptions.xml	2010-01-07 17:25:17 +0000
@@ -15,7 +15,7 @@
                 homepage="http://code.google.com/p/adblock-chinalist/"/>
   <subscription title="Filter von Dr.Evil (Deutschland)"
                 url="http://maltekraus.de/Firefox/adblock.txt"
-                homepage="http://www.camp-firefox.de/forum/viewtopic.php?t=58194"/>
+                homepage="http://www.camp-firefox.de/forum/viewtopic.php?t=55998"/>
   <subscription title="Morpeh Rus List (Россия) + EasyList"
                 url="https://easylist-downloads.adblockplus.org/morpeh+easylist.txt"
                 homepage="http://adblockplus.mihalkin.ru/"/>
@@ -25,4 +25,7 @@
   <subscription title="ROList (România) + EasyList"
                 url="https://easylist-downloads.adblockplus.org/rolist+easylist.txt"
                 homepage="http://www.picpoc.ro/"/>
+  <subscription title="Việt Nam List (Việt Nam) + EasyList"
+                url="https://easylist-downloads.adblockplus.org/abpvn+easylist.txt"
+                homepage="http://code.google.com/p/adblockplus-vietnam/"/>
 </subscriptions>

=== modified file 'install.rdf'
--- install.rdf	2009-12-12 18:20:36 +0000
+++ install.rdf	2010-01-07 17:25:17 +0000
@@ -42,8 +42,8 @@
   <em:targetApplication>
     <Description>
     <em:id>songbird@songbirdnest.com</em:id>
-    <em:minVersion>1.2.0</em:minVersion>
-    <em:maxVersion>1.5.0a</em:maxVersion>
+    <em:minVersion>1.4.0</em:minVersion>
+    <em:maxVersion>1.7.0a</em:maxVersion>
     </Description>
   </em:targetApplication>
 

=== modified file 'version'
--- version	2009-12-12 18:20:36 +0000
+++ version	2010-01-07 17:25:17 +0000
@@ -1,1 +1,1 @@
-1.1.2
\ No newline at end of file
+1.1.3
\ No newline at end of file

